# imports - module imports
from pipupgrade.commands import command as main

if __name__ == "__main__":
    main()